@@ -1,7 +1,7 @@
 
 #include <iostream>
 #include <fstream>
-#include <rcsc/rcg/parser.h>
+#include <rcsc/rcg/factory.h>
 #include "result_writer.h"
 
 int
@@ -21,7 +21,7 @@ main( int argc, char** argv )
         return 0;
     }
 
-    const rcsc::rcg::ParserPtr parser( rcsc::rcg::ParserHolder::instance().get( fin ) );
+    rcsc::rcg::ParserPtr parser = rcsc::rcg::make_parser( fin );
 
     if ( ! parser )
     {
