@@ -81,7 +81,10 @@ public:
         : public std::binary_function< KeepDribbleInfo,
                                        KeepDribbleInfo,
                                        bool > {
-
+        /*!
+          \brief compare the dribble score
+          \return true if lhs is better than rhs
+         */
         result_type operator()( const first_argument_type & lhs,
                                 const second_argument_type & rhs ) const
           {
