@@ -48,8 +48,8 @@
 #include <rcsc/player/audio_sensor.h>
 #include <rcsc/player/player_agent.h>
 #include <rcsc/player/debug_client.h>
-#include <rcsc/player/logger.h>
 #include <rcsc/player/say_message_builder.h>
+#include <rcsc/common/logger.h>
 #include <rcsc/common/server_param.h>
 #include <rcsc/geom/ray_2d.h>
 #include <rcsc/geom/rect_2d.h>
@@ -59,6 +59,8 @@
 
 #include <functional>
 
+//#define USE_CHANGE_VIEW
+
 namespace rcsc {
 
 /*!
@@ -700,8 +702,13 @@ Body_Dribble2007::doKickTurnsDash( PlayerAgent * agent,
                                     std::fabs( dash_power ),
                                     ( dash_power < 0.0 ), // back_dash
                                     wm.time() ) );
-
     say( agent, target_point, n_turn + 1 );
+#ifdef USE_CHANGE_VIEW
+    if ( n_turn + 1 >= 3 )
+    {
+        agent->setViewAction( new View_Normal() );
+    }
+#endif
 
     // execute first kick
     return agent->doKick( required_kick_power,
@@ -840,8 +847,13 @@ Body_Dribble2007::doKickTurnsDashes(  PlayerAgent * agent,
                                         std::fabs( dash_power ),
                                         ( dash_power < 0.0 ), // back_dash
                                         wm.time() ) );
-
         say( agent, target_point, n_dash + n_turn );
+#ifdef USE_CHANGE_VIEW
+        if ( n_turn + n_dash >= 3 )
+        {
+            agent->setViewAction( new View_Normal() );
+        }
+#endif
         return true;
     }
 
@@ -1057,6 +1069,13 @@ Body_Dribble2007::doKickDashes( PlayerAgent * agent,
                                     ( dash_power < 0.0 ), // back_dash
                                     wm.time() ) );
     say( agent, target_point, dash_count );
+#ifdef USE_CHANGE_VIEW
+    if ( dash_count >= 2 )
+    {
+        agent->setViewAction( new View_Normal() );
+    }
+#endif
+
     dlog.addText( Logger::DRIBBLE,
                   "%s: doKickDashes() register intention. dash_count=%d"
                   ,__FILE__,
@@ -1403,6 +1422,13 @@ Body_Dribble2007::doKickDashesWithBall( PlayerAgent * agent,
                                     ( dash_power < 0.0 ), // back_dash
                                     wm.time() ) );
     say( agent, target_point, std::min( dribble->dash_count_, dash_count ) );
+#ifdef USE_CHANGE_VIEW
+    if ( std::min( dribble->dash_count_, dash_count ) >= 2 )
+    {
+        agent->setViewAction( new View_Normal() );
+    }
+#endif
+
     return true;
 }
 
@@ -1535,7 +1561,7 @@ Body_Dribble2007::existKickableOpponent( const WorldModel & wm,
         // goalie's catchable check
         if ( (*it)->goalie() )
         {
-            if ( ball_pos.x > ServerParam::i().theirPenaltyAreaLine()
+            if ( ball_pos.x > ServerParam::i().theirPenaltyAreaLineX()
                  && ball_pos.absY() < ServerParam::i().penaltyAreaHalfWidth() )
             {
                 double d = (*it)->pos().dist( ball_pos );
