@@ -38,8 +38,8 @@
 #include "basic_actions.h"
 #include "body_stop_dash.h"
 
-#include <rcsc/player/logger.h>
 #include <rcsc/player/player_agent.h>
+#include <rcsc/common/logger.h>
 #include <rcsc/common/server_param.h>
 #include <rcsc/soccer_math.h>
 #include <rcsc/math_util.h>
