@@ -36,9 +36,9 @@
 #include "body_go_to_point_dodge.h"
 #include "body_go_to_point.h"
 
-#include <rcsc/player/logger.h>
 #include <rcsc/player/player_agent.h>
-#include <rcsc/param/server_param.h>
+#include <rcsc/common/logger.h>
+#include <rcsc/common/server_param.h>
 #include <rcsc/geom/line_2d.h>
 #include <rcsc/math_util.h>
 
