@@ -38,10 +38,10 @@
 #include <rcsc/action/basic_actions.h>
 #include <rcsc/action/body_go_to_point.h>
 
-#include <rcsc/player/logger.h>
 #include <rcsc/player/intercept_table.h>
 #include <rcsc/player/player_agent.h>
 #include <rcsc/player/debug_client.h>
+#include <rcsc/common/logger.h>
 #include <rcsc/common/server_param.h>
 #include <rcsc/soccer_math.h>
 #include <rcsc/math_util.h>
@@ -96,6 +96,12 @@ Body_Intercept2007::execute( PlayerAgent * agent )
                   best_intercept.reachCycle(),
                   best_intercept.turnCycle(), best_intercept.dashCycle() );
 
+//     if ( 3 <= best_intercept.reachCycle()
+//          && best_intercept.reachCycle() < 6 )
+//     {
+//         agent->setViewAction( new View_Normal() );
+//     }
+
     Vector2D target_point = wm.ball().inertiaPoint( best_intercept.reachCycle() );
     agent->debugClient().setTarget( target_point );
 
