@@ -40,8 +40,8 @@
 #include "body_hold_ball.h"
 #include "body_kick_to_relative.h"
 
-#include <rcsc/player/logger.h>
 #include <rcsc/player/player_agent.h>
+#include <rcsc/common/logger.h>
 #include <rcsc/common/server_param.h>
 #include <rcsc/geom/circle_2d.h>
 #include <rcsc/geom/ray_2d.h>
@@ -107,6 +107,10 @@ Body_KickTwoStep::execute( PlayerAgent * agent )
                       achieved_vel.x, achieved_vel.y, achieved_vel.r(),
                       accel.x, accel.y,
                       kick_power, kick_dir.degree() );
+        M_ball_result_pos = wm.ball().pos() + achieved_vel;
+        M_ball_result_vel = achieved_vel * ServerParam::i().ballDecay();;
+        M_kick_step = 1;
+
         return agent->doKick( kick_power, kick_dir );
     }
 
@@ -124,6 +128,8 @@ Body_KickTwoStep::execute( PlayerAgent * agent )
                             agent,
                             M_enforce_kick ) )
     {
+        M_kick_step = 2;
+
         if ( M_enforce_kick
              && next_vel.r2() < square( M_first_speed ) )
         {
@@ -134,6 +140,7 @@ Body_KickTwoStep::execute( PlayerAgent * agent )
             if ( one_kick_max_vel.r2() > next_vel.r2() )
             {
                 next_vel = one_kick_max_vel;
+                M_kick_step = 1;
             }
 
             if ( next_vel.r() < M_first_speed * 0.9 )
@@ -141,6 +148,7 @@ Body_KickTwoStep::execute( PlayerAgent * agent )
                 dlog.addText( Logger::KICK,
                               "%s:%d: failed enforce kick. hold ball"
                               ,__FILE__, __LINE__ );
+                M_kick_step = 0;
 
                 return Body_HoldBall( true, // turn to target
                                       M_target_point
@@ -163,6 +171,9 @@ Body_KickTwoStep::execute( PlayerAgent * agent )
                       kick_power, kick_dir.degree() );
         agent->debugClient().addCircle( wm.ball().pos() + next_vel,
                                         0.05 );
+        M_ball_result_pos = wm.ball().pos() + next_vel;
+        M_ball_result_vel = next_vel * ServerParam::i().ballDecay();
+
         return agent->doKick( kick_power, kick_dir );
     }
 
@@ -221,7 +232,7 @@ Body_KickTwoStep::is_opp_kickable( const PlayerAgent * agent,
         }
         // check opponent goalie
         else if ( (*it)->goalie()
-                  && (*it)->pos().x > ServerParam::i().theirPenaltyAreaLine() + 1.0
+                  && (*it)->pos().x > ServerParam::i().theirPenaltyAreaLineX() + 1.0
                   && ( (*it)->pos().absY()
                        < ServerParam::i().penaltyAreaHalfWidth() - 1.0 )
                   && ( rel_pos.dist( (*it)->rpos() + (*it)->vel() )
@@ -472,8 +483,8 @@ Body_KickTwoStep::simulate_two_kick( Vector2D * achieved_vel,
         const Vector2D my_next_vel
             = my_vel * agent->world().self().playerType().playerDecay();
 
-        const std::vector< SubTarget >::iterator end = subtargets.end();
-        for ( std::vector< SubTarget >::iterator it = subtargets.begin();
+        const std::vector< SubTarget >::const_iterator end = subtargets.end();
+        for ( std::vector< SubTarget >::const_iterator it = subtargets.begin();
               it != end;
               ++it )
         {
