@@ -62,7 +62,7 @@ public:
         /*!
           \brief construct with all member variables
           \param ball_pos ball position
-          \param ball vel ball velocity
+          \param ball_vel ball velocity
           \param squared opponent distance
          */
         SubTarget( const Vector2D & ball_pos,
@@ -84,6 +84,13 @@ private:
     double M_first_speed;
     //! if true, ball should be released enforcely
     const bool M_enforce_kick;
+
+    //! result ball position
+    Vector2D M_ball_result_pos;
+    //! result ball velocity
+    Vector2D M_ball_result_vel;
+    //! estimated kick step
+    int M_kick_step;
 public:
     /*!
       \brief construct with all parameters
@@ -97,6 +104,9 @@ public:
         : M_target_point( target_point )
         , M_first_speed( first_speed )
         , M_enforce_kick( enforce )
+        , M_ball_result_pos( Vector2D::INVALIDATED )
+        , M_ball_result_vel( Vector2D::INVALIDATED )
+        , M_kick_step( 0 )
       { }
 
     /*!
@@ -107,6 +117,36 @@ public:
     bool execute( PlayerAgent * agent );
 
 
+    /*!
+      \brief get the result ball position
+      \return ball position after kick
+     */
+    const
+    Vector2D & ballResultPos() const
+      {
+          return M_ball_result_pos;
+      }
+
+    /*!
+      \brief get the result ball velocity
+      \return ball velocity after kick
+     */
+    const
+    Vector2D & ballResultVel() const
+      {
+          return M_ball_result_vel;
+      }
+
+    /*!
+      \brief get the estimated kick steps
+      \return estimated kick steps
+     */
+    int kickStep() const
+      {
+          return M_kick_step;
+      }
+
+
     /*!
       \brief check if opponent is kickable at rel_pos
       \param agent agent itself
