@@ -35,9 +35,9 @@
 
 #include "intention_time_limit_action.h"
 
-#include <rcsc/player/logger.h>
 #include <rcsc/player/player_agent.h>
 #include <rcsc/player/soccer_action.h>
+#include <rcsc/common/logger.h>
 #include <rcsc/common/server_param.h>
 
 namespace rcsc {
