@@ -37,8 +37,8 @@
 
 #include "basic_actions.h"
 
-#include <rcsc/player/logger.h>
 #include <rcsc/player/player_agent.h>
+#include <rcsc/common/logger.h>
 #include <rcsc/common/server_param.h>
 #include <rcsc/geom/rect_2d.h>
 
@@ -64,9 +64,6 @@ Neck_ScanField::execute( PlayerAgent * agent )
         s_last_calc_time = agent->world().time();
         s_last_calc_view_width = agent->effector().queuedNextViewWidth();
 
-
-
-
         s_cached_target_angle = calcAngle( agent );
     }
 
