@@ -35,21 +35,26 @@
 
 #include "coach_agent.h"
 
+#include "coach_audio_sensor.h"
 #include "coach_config.h"
 #include "coach_command.h"
 #include "global_visual_sensor.h"
 #include "global_world_model.h"
 
 #include <rcsc/common/basic_client.h>
+#include <rcsc/common/logger.h>
 #include <rcsc/common/server_param.h>
 #include <rcsc/common/player_param.h>
 #include <rcsc/common/player_type.h>
+#include <rcsc/common/team_graphic.h>
+#include <rcsc/common/audio_memory.h>
 
 #include <rcsc/param/param_map.h>
 #include <rcsc/param/conf_file_parser.h>
 #include <rcsc/param/cmd_line_parser.h>
 
 #include <sstream>
+#include <cstring>
 
 namespace rcsc {
 
@@ -78,6 +83,9 @@ struct CoachAgentImpl {
     //! visual sensor data
     GlobalVisualSensor visual_;
 
+    //! audio sensor
+    CoachAudioSensor audio_;
+
     /*!
       \brief initialize all members
     */
@@ -117,12 +125,22 @@ CoachAgentImpl::updateCurrentTime( const long & new_time,
     {
         if ( new_time != current_time_.cycle() )
         {
+            dlog.addText( Logger::LEVEL_ANY,
+                          "CYCLE %ld-0 --------------------"
+                          " return from cycle stop",
+                          new_time );
             if ( new_time - 1 != current_time_.cycle() )
             {
                 std::cerr << "coach: server cycle stopped mode:"
                           << " previous server time is incorrect?? "
                           << current_time_ << " -> " << new_time
                           << std::endl;
+                dlog.addText( Logger::SYSTEM,
+                              "server cycle stopped mode:"
+                              " previous server time is incorrect?? "
+                              " (%ld, %ld) -> %ld",
+                              current_time_.cycle(), current_time_.stopped(),
+                              new_time );
             }
 
             current_time_.assign( new_time, 0 );
@@ -131,6 +149,10 @@ CoachAgentImpl::updateCurrentTime( const long & new_time,
         {
             if ( by_see_global )
             {
+                dlog.addText( Logger::LEVEL_ANY,
+                              "CYCLE %ld-%ld --------------------"
+                              " stopped time was updated by see_global",
+                              current_time_.cycle(), current_time_.stopped() + 1 );
                 current_time_.assign( current_time_.cycle(),
                                       current_time_.stopped() + 1 );
             }
@@ -139,6 +161,12 @@ CoachAgentImpl::updateCurrentTime( const long & new_time,
     // normal case
     else
     {
+        if ( current_time_.cycle() != new_time )
+        {
+            dlog.addText( Logger::LEVEL_ANY,
+                          "CYCLE %ld-0  -------------------------------------------------",
+                          new_time );
+        }
         current_time_.assign( new_time, 0 );
     }
 }
@@ -176,7 +204,9 @@ CoachAgent::CoachAgent()
     : SoccerAgent()
     , M_impl( new CoachAgentImpl )
 {
+    boost::shared_ptr< AudioMemory > audio_memory( new AudioMemory );
 
+    M_worldmodel.setAudioMemory( audio_memory );
 }
 
 /*-------------------------------------------------------------------*/
@@ -202,6 +232,17 @@ CoachAgent::visualSensor() const
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+const
+CoachAudioSensor &
+CoachAgent::audioSensor() const
+{
+    return M_impl->audio_;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 bool
 CoachAgent::initImpl( CmdLineParser & cmd_parser )
@@ -243,6 +284,24 @@ CoachAgent::initImpl( CmdLineParser & cmd_parser )
     //    cmd_parser.printError( std::cerr );
     //    std::cerr << std::endl;
     //}
+
+    if ( config().debug() )
+    {
+        dlog.setLogFlag( &world().time(), Logger::SYSTEM, config().debugSystem() );
+        dlog.setLogFlag( &world().time(), Logger::SENSOR, config().debugSensor() );
+        dlog.setLogFlag( &world().time(), Logger::WORLD, config().debugWorld() );
+        dlog.setLogFlag( &world().time(), Logger::ACTION, config().debugAction() );
+        dlog.setLogFlag( &world().time(), Logger::INTERCEPT, config().debugIntercept() );
+        dlog.setLogFlag( &world().time(), Logger::KICK, config().debugKick() );
+        dlog.setLogFlag( &world().time(), Logger::DRIBBLE, config().debugDribble() );
+        dlog.setLogFlag( &world().time(), Logger::PASS, config().debugPass() );
+        dlog.setLogFlag( &world().time(), Logger::CROSS, config().debugCross() );
+        dlog.setLogFlag( &world().time(), Logger::SHOOT, config().debugShoot() );
+        dlog.setLogFlag( &world().time(), Logger::CLEAR, config().debugClear() );
+        dlog.setLogFlag( &world().time(), Logger::TEAM, config().debugTeam() );
+        dlog.setLogFlag( &world().time(), Logger::ROLE, config().debugRole() );
+    }
+
     return true;
 }
 
@@ -322,6 +381,7 @@ CoachAgent::handleMessage()
     {
         action();
     }
+#if 0
     else if ( ! ServerParam::i().synchMode() )
     {
         if ( M_impl->last_decision_time_ != M_impl->current_time_
@@ -330,6 +390,7 @@ CoachAgent::handleMessage()
             action();
         }
     }
+#endif
 }
 
 /*-------------------------------------------------------------------*/
@@ -337,7 +398,7 @@ CoachAgent::handleMessage()
 
 */
 void
-CoachAgent::handleTimeout( const int timeout_count,
+CoachAgent::handleTimeout( const int /*timeout_count*/,
                            const int waited_msec )
 {
     if ( ! M_client )
@@ -373,6 +434,19 @@ CoachAgent::handleTimeout( const int timeout_count,
         //<< std::endl;
         doCheckBall();
     }
+
+
+    if ( M_impl->last_decision_time_ != M_impl->current_time_ )
+    {
+        if ( M_impl->visual_.time() == M_impl->current_time_
+             || waited_msec >= 20 * ServerParam::i().slowDownFactor() )
+        {
+            dlog.addText( Logger::SYSTEM,
+                          "----- TIMEOUT DECISION !! [%d]ms from last sensory",
+                          waited_msec );
+            action();
+        }
+    }
 }
 
 /*-------------------------------------------------------------------*/
@@ -388,6 +462,26 @@ CoachAgent::handleExit()
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+CoachAgent::addSayMessageParser( boost::shared_ptr< SayMessageParser > parser )
+{
+    M_impl->audio_.addParser( parser );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+CoachAgent::removeSayMessageParser( const char header )
+{
+    M_impl->audio_.removeParser( header );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 void
 CoachAgent::finalize()
@@ -534,6 +628,33 @@ CoachAgent::analyzeInit( const char * msg )
                        : RIGHT );
     M_worldmodel.init( side_id );
 
+    if ( config().debug() )
+    {
+        std::ostringstream ostrm;
+        std::string file_dir = config().logDir();
+        if ( file_dir.empty() )
+        {
+            ostrm << "./";
+        }
+        else
+        {
+            ostrm << file_dir;
+            if ( file_dir[file_dir.length() - 1] != '/' )
+            {
+                ostrm << '/';
+            }
+        }
+        ostrm << config().teamName() << "-coach"
+              << config().logExt();
+        dlog.open( ostrm.str().c_str() );
+        if ( ! dlog.isOpen() )
+        {
+            std::cerr << config().teamName() << " coach: "
+                      << " Failed to open file [" << ostrm.str() << "]"
+                      << std::endl;
+        }
+    }
+
     // send specific settings
     // if we intend to advise to the team,
     // set visual sensory
@@ -542,6 +663,11 @@ CoachAgent::analyzeInit( const char * msg )
         doEye( true );
     }
 
+    if ( config().hearSay() )
+    {
+        M_impl->audio_.setTeamName( config().teamName() );
+    }
+
     // set compression level
     if ( 0 < config().compression()
          && config().compression() <= 9 )
@@ -561,7 +687,7 @@ CoachAgent::analyzeCycle( const char * msg,
 {
     char id[16];
     long cycle = 0;
-    if ( std::sscanf( msg, "(%s %ld ",
+    if ( std::sscanf( msg, "(%15s %ld ",
                       id, &cycle ) != 2 )
     {
         std::cerr << config().teamName()
@@ -691,6 +817,10 @@ CoachAgent::analyzeHearPlayer( const char * msg )
     // (hear <time> (player "<teamname>" <unum>) "<message>")
     // (hear <time> (p "<teamname>" <unum>) "<message>")
 
+    if ( config().hearSay() )
+    {
+        M_impl->audio_.parsePlayerMessage( msg, M_impl->current_time_ );
+    }
 }
 
 /*-------------------------------------------------------------------*/
@@ -706,27 +836,26 @@ CoachAgent::analyzeChangePlayerType( const char * msg )
 
     int unum = -1, type = -1;
 
-    if ( std::sscanf( msg, "(ok change_player_type %d %d)",
+    if ( std::sscanf( msg, " ( ok change_player_type %d %d ) ",
                       &unum, &type ) == 2 )
     {
-        M_worldmodel.recvChangePlayerType( world().ourSide(),
-                                           unum,
-                                           static_cast< HeteroID >( type ) );
+        // do nothing
     }
-    else if ( std::sscanf( msg, "(change_player_type %d %d)",
+    else if ( std::sscanf( msg, " ( change_player_type %d %d ) ",
                            &unum, &type ) == 2 )
     {
         // teammate
-        // do nothing
+        M_worldmodel.setPlayerType( world().ourSide(),
+                                    unum,
+                                    type );
     }
-    else if ( std::sscanf( msg, "(change_player_type %d)",
+    else if ( std::sscanf( msg, " ( change_player_type %d ) ",
                            &unum ) == 1 )
     {
         // opponent
-        SideID opp_side = ( world().ourSide() == LEFT
-                            ? RIGHT
-                            : LEFT );
-        M_worldmodel.recvChangePlayerType( opp_side, unum, Hetero_Unknown );
+        M_worldmodel.setPlayerType( world().theirSide(),
+                                    unum,
+                                    Hetero_Unknown );
     }
     else
     {
@@ -743,8 +872,6 @@ CoachAgent::analyzeChangePlayerType( const char * msg )
 void
 CoachAgent::analyzePlayerType( const char * msg )
 {
-    //std::cout << "Coach received player_type " << std::endl;
-
     PlayerType player_type( ServerParam::i(),
                             msg, config().version() );
     PlayerTypeSet::instance().insert( player_type );
@@ -757,7 +884,6 @@ CoachAgent::analyzePlayerType( const char * msg )
 void
 CoachAgent::analyzePlayerParam( const char * msg )
 {
-    //std::cout << "Coach received player_param " << std::endl;
     PlayerParam::instance().parse( msg, config().version() );
     //PlayerParam::i().print( std::cout );
 }
@@ -769,17 +895,18 @@ CoachAgent::analyzePlayerParam( const char * msg )
 void
 CoachAgent::analyzeServerParam( const char * msg )
 {
-    //std::cout << " parsed server_param " << std::endl;
     ServerParam::instance().parse( msg, config().version() );
+    PlayerTypeSet::instance().resetDefaultType( ServerParam::i() );
 
-    if ( ServerParam::i().slowDownFactor() != 1 )
+    M_worldmodel.initFreeformCount();
+
+    if ( ! ServerParam::i().synchMode()
+         && ServerParam::i().slowDownFactor() > 1 )
     {
         long interval = ( config().intervalMSec()
                           * ServerParam::i().slowDownFactor() );
         M_client->setIntervalMSec( interval );
     }
-
-    M_worldmodel.initFreeformCount();
 }
 
 /*-------------------------------------------------------------------*/
@@ -787,7 +914,7 @@ CoachAgent::analyzeServerParam( const char * msg )
 
 */
 void
-CoachAgent::analyzeCLangVer( const char * msg )
+CoachAgent::analyzeCLangVer( const char * )
 {
     //     std::cerr << config().teamName()
     //               << " coach: "
@@ -810,8 +937,13 @@ CoachAgent::analyzeOK( const char * msg )
     {
         // nothing to do
     }
+    else if ( ! std::strncmp( msg, "(ok team_graphic ",
+                              std::strlen( "(ok team_graphic " ) ) )
+    {
+        analyzeOKTeamGraphic( msg );
+    }
     else if ( ! std::strncmp( msg, "(ok look ",
-                         std::strlen( "(ok look " ) ) )
+                              std::strlen( "(ok look " ) ) )
     {
         std::cout << config().teamName()
                   << " coach: "
@@ -872,6 +1004,35 @@ CoachAgent::analyzeOK( const char * msg )
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+CoachAgent::analyzeOKTeamGraphic( const char * msg )
+{
+    // "(ok team_graphic <x> <y>)"
+    // "(ok team_graphic <x> <y>)"
+
+    int x = -1, y = -1;
+
+    if ( std::sscanf( msg,
+                      "(ok team_graphic %d %d)",
+                      &x, &y ) != 2
+         || x < 0
+         || y < 0 )
+    {
+        std::cout << config().teamName()
+                  << " coach: "
+                  << world().time()
+                  << " recv illegal message. " << msg
+                  << std::endl;
+        return;
+    }
+
+    M_team_graphic_ok_set.insert( TeamGraphic::Index( x, y ) );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 void
 CoachAgent::analyzeTeamNames( const char * msg )
@@ -1069,36 +1230,64 @@ CoachAgent::doEye( bool on )
 */
 bool
 CoachAgent::doChangePlayerType( const int unum,
-                                const HeteroID type )
+                                const int type )
 {
     if ( unum < 1 || 11 < unum )
     {
         std::cerr << config().teamName()
-                  << "coach: :"
+                  << "coach: "
                   << world().time()
-                  << " doChangePlayerType. invalid player number = "
+                  << " doChangePlayerType. Illegal player number = "
                   << unum
                   << std::endl;
         return false;
     }
-    if ( type < Hetero_Default || Hetero_MAX <= type )
+
+    if ( type < Hetero_Default
+         || PlayerParam::i().playerTypes() <= type )
     {
         std::cerr << config().teamName()
                   << " coach: "
                   << world().time()
-                  << "doChangePlayerType. invalid player type = "
+                  << "doChangePlayerType. Illegal player type = "
                   << type
                   << std::endl;
         return false;
     }
 
-    CoachChangePlayerTypeCommand com( unum, type  );
+    CoachChangePlayerTypeCommand com( unum, type );
     return sendCommand( com );
 }
 
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+bool
+CoachAgent::doChangePlayerTypes( const std::vector< std::pair< int, int > > & types )
+{
+    if ( types.empty() )
+    {
+        return false;
+    }
+
+    //CoachChangePlayerTypesCommand com( types );
+    //return sendCommand( com );
+
+    bool result = true;
+    for ( std::vector< std::pair< int, int > >::const_iterator it = types.begin();
+          it != types.end();
+          ++it )
+    {
+        result = doChangePlayerType( it->first, it->second );
+    }
+
+    return result;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 bool
 CoachAgent::doSayFreeform( const std::string & msg )
@@ -1129,7 +1318,7 @@ CoachAgent::doSayFreeform( const std::string & msg )
             return false;
         }
 
-        // only message string is sent.
+        // raw message string is sent.
         // (say <message>)
 
         M_worldmodel.incFreeformSendCount();
@@ -1168,4 +1357,52 @@ CoachAgent::doSayFreeform( const std::string & msg )
     return ( M_client->sendMessage( freeform_msg.c_str() ) > 0 );
 }
 
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+bool
+CoachAgent::doTeamGraphic( const int x,
+                           const int y,
+                           const TeamGraphic & team_graphic )
+{
+    static int send_count = 0;
+    static GameTime send_time( -1, 0 );
+
+    if ( send_time != M_impl->current_time_ )
+    {
+        send_count = 0;
+    }
+
+    send_time = M_impl->current_time_;
+    ++send_count;
+
+    if ( send_count > config().maxTeamGraphicPerCycle() ) // XXX Magic Number
+    {
+        return false;
+    }
+
+    TeamGraphic::Index index( x, y );
+    TeamGraphic::Map::const_iterator tile = team_graphic.tiles().find( index );
+
+    if ( tile == team_graphic.tiles().end() )
+    {
+        std::cerr << config().teamName()
+                  << " coach: "
+                  << world().time()
+                  << " ***WARNING*** The xpm tile ("
+                  << x << ',' << y << ") does not found in the team graphic."
+                  << std::endl;
+        return false;
+    }
+
+    std::ostringstream ostr;
+
+    ostr << "(team_graphic (" << x << ' ' << y << ' ';
+    tile->second->print( ostr );
+    ostr << "))";
+
+    return ( M_client->sendMessage( ostr.str().c_str() ) > 0 );
+}
+
 }
