@@ -196,7 +196,7 @@ public:
       \param msg message
      */
     void addText( const boost::int32_t id,
-                  char * msg, ... );
+                  const char * msg, ... );
 
     /*!
       \brief add point info to buffer with cycle, level & message tag 'p'
