@@ -40,6 +40,7 @@
 #include <boost/random.hpp>
 #include <sstream>
 #include <algorithm>
+#include <ctime>
 
 namespace rcsc {
 
@@ -81,7 +82,7 @@ FormationBPN::Param::getPosition( const Vector2D & ball_pos,
                                   const Formation::SideType type ) const
 {
     double msign = 1.0;
-    if ( type == Formation::MIRROR ) msign =  -1.0;
+    if ( type == Formation::SYNMETRY ) msign =  -1.0;
     if ( type == Formation::CENTER && ball_pos.y > 0.0 ) msign = -1.0;
 
     PosNet::input_array input;
@@ -284,14 +285,14 @@ FormationBPN::createDefaultParam()
     // 11(10): right forward
     createNewRole( 1, "Goalie", Formation::CENTER );
     createNewRole( 2, "CenterBack", Formation::SIDE );
-    setMirrorType( 3, 2 );
+    setSynmetryType( 3, 2 );
     createNewRole( 4, "SideBack", Formation::SIDE );
-    setMirrorType( 5, 4 );
+    setSynmetryType( 5, 4 );
     createNewRole( 6, "DefensiveHalf", Formation::CENTER );
     createNewRole( 7, "OffensiveHalf", Formation::SIDE );
-    setMirrorType( 8, 7 );
+    setSynmetryType( 8, 7 );
     createNewRole( 9, "SideForward", Formation::SIDE );
-    setMirrorType( 10, 9 );
+    setSynmetryType( 10, 9 );
     createNewRole( 11, "CenterForward", Formation::CENTER );
 
     Snapshot snap;
@@ -325,14 +326,14 @@ FormationBPN::createDefaultParam()
     createNewRole( 1, "Goalie", Formation::CENTER );
     createNewRole( 2, "CenterBack", Formation::CENTER );
     createNewRole( 3, "SideBack", Formation::SIDE );
-    setMirrorType( 4, 3 );
+    setSynmetryType( 4, 3 );
     createNewRole( 5, "DefensiveHalf", Formation::SIDE );
-    setMirrorType( 6, 5 );
+    setSynmetryType( 6, 5 );
     createNewRole( 7, "SideHalf", Formation::SIDE );
-    setMirrorType( 8, 7 );
+    setSynmetryType( 8, 7 );
     createNewRole( 9, "OffensiveHalf", Formation::CENTER );
     createNewRole( 10, "Forward", Formation::SIDE );
-    setMirrorType( 11, 10 );
+    setSynmetryType( 11, 10 );
 #endif
 }
 
@@ -407,7 +408,7 @@ FormationBPN::createNewRole( const int unum,
     else
     {
         std::cerr << __FILE__ << ":" << __LINE__
-                  << " *** ERROR *** You cannot create a new parameter for mirror type."
+                  << " *** ERROR *** You cannot create a new parameter for synmetry type."
                   << std::endl;
         return;
     }
@@ -446,8 +447,8 @@ FormationBPN::getPosition( const int unum,
     }
 
     Formation::SideType type = Formation::SIDE;
-    if ( M_mirror_number[unum - 1] > 0 )  type = Formation::MIRROR;
-    if ( M_mirror_number[unum - 1] == 0 ) type = Formation::CENTER;
+    if ( M_synmetry_number[unum - 1] > 0 )  type = Formation::SYNMETRY;
+    if ( M_synmetry_number[unum - 1] == 0 ) type = Formation::CENTER;
 
     return ptr->getPosition( ball_pos, type );
 }
@@ -489,9 +490,9 @@ FormationBPN::train( const std::list< Snapshot > & train_data )
     {
         int number = unum;
         Formation::SideType type = Formation::SIDE;
-        if ( isMirrorType( unum ) )
+        if ( isSynmetryType( unum ) )
         {
-            std::cerr << "  Training. player " << unum << " >>> mirror type "
+            std::cerr << "  Training. player " << unum << " >>> synmetry type "
                       << std::endl;
             continue;
         }
@@ -621,7 +622,7 @@ FormationBPN::getParam( const int unum )
             ( static_cast< FormationBPN::Param * >( 0 ) );
     }
 
-    if ( M_mirror_number[unum - 1] > 0 )
+    if ( M_synmetry_number[unum - 1] > 0 )
     {
         return boost::shared_ptr< FormationBPN::Param >
             ( static_cast< FormationBPN::Param * >( 0 ) );
@@ -658,9 +659,9 @@ FormationBPN::param( const int unum ) const
             ( static_cast< FormationBPN::Param * >( 0 ) );
     }
 
-    const int player_number = ( M_mirror_number[unum - 1] <= 0 // center or original
+    const int player_number = ( M_synmetry_number[unum - 1] <= 0 // center or original
                                 ? unum
-                                : M_mirror_number[unum - 1] );
+                                : M_synmetry_number[unum - 1] );
 
     std::map< int, boost::shared_ptr< FormationBPN::Param > >::const_iterator
         it = M_param_map.find( player_number );
@@ -700,19 +701,19 @@ FormationBPN::read( std::istream & is )
     }
 
     //---------------------------------------------------
-    // check mirror number circuration reference
+    // check synmetry number circuration reference
     for ( int i = 0; i < 11; ++i )
     {
-        int refered_unum = M_mirror_number[i];
+        int refered_unum = M_synmetry_number[i];
         if ( refered_unum <= 0 ) continue;
-        if ( M_mirror_number[refered_unum - 1] > 0 )
+        if ( M_synmetry_number[refered_unum - 1] > 0 )
         {
             std::cerr << __FILE__ << ":" << __LINE__
                       << " *** ERROR *** failed to read formation."
-                      << " Bad mirroring. player "
+                      << " Bad synmetrying. player "
                       << i + 1
                       << " mirro = " << refered_unum
-                      << " is already mirroring player"
+                      << " is already synmetrying player"
                       << std::endl;
             return false;
         }
@@ -742,11 +743,11 @@ FormationBPN::readPlayers( std::istream & is )
 
         // check id
         int unum = 0;
-        int mirror = 0;
+        int synmetry = 0;
         int n_read = 0;
         if ( std::sscanf( line_buf.c_str(),
                           " player %d %d %n ",
-                          &unum, &mirror,
+                          &unum, &synmetry,
                           &n_read ) != 2
              || n_read == 0 )
         {
@@ -766,33 +767,33 @@ FormationBPN::readPlayers( std::istream & is )
                       << std::endl;
             return false;
         }
-        if ( mirror == unum )
+        if ( synmetry == unum )
         {
             std::cerr << __FILE__ << ":" << __LINE__
                       << " *** ERROR *** failed to read formation."
-                      << " Invalid mirror number. at "
+                      << " Invalid synmetry number. at "
                       << i
                       << " mirroing player itself. unum = " << unum
-                      << "  mirror = " << mirror
+                      << "  synmetry = " << synmetry
                       << std::endl;
             return false;
         }
-        if ( 11 < mirror )
+        if ( 11 < synmetry )
         {
             std::cerr << __FILE__ << ":" << __LINE__
                       << " *** ERROR *** failed to read formation."
-                      << " Invalid mirror number. at "
+                      << " Invalid synmetry number. at "
                       << i
-                      << "  Mirror number is out of range. unum = " << unum
-                      << "  mirror = " << mirror
+                      << "  Synmetry number is out of range. unum = " << unum
+                      << "  synmetry = " << synmetry
                       << std::endl;
             return false;
         }
 
-        M_mirror_number[i] = mirror;
+        M_synmetry_number[i] = synmetry;
 
-        // this player is mirror type
-        if ( mirror > 0 )
+        // this player is synmetry type
+        if ( synmetry > 0 )
         {
             ++player_read;
             continue;
@@ -844,8 +845,8 @@ FormationBPN::print( std::ostream & os ) const
     for ( int i = 0; i < 11; ++i )
     {
         const int unum = i + 1;
-        os << "player " << unum << " " << M_mirror_number[i] << " ";
-        if ( M_mirror_number[i] > 0 )
+        os << "player " << unum << " " << M_synmetry_number[i] << " ";
+        if ( M_synmetry_number[i] > 0 )
         {
             os << '\n';
             continue;
