@@ -310,7 +310,7 @@ FormationDT::getPosition( const int unum,
         return Vector2D::INVALIDATED;
     }
 
-    DelaunayTriangulation::TrianglePtr tri
+    const DelaunayTriangulation::Triangle * tri
         = M_triangulation.findTriangleContains( focus_point );
 
     // linear interpolation
@@ -327,7 +327,7 @@ FormationDT::getPositions( const Vector2D & focus_point,
 {
     positions.clear();
 
-    DelaunayTriangulation::TrianglePtr tri
+    const DelaunayTriangulation::Triangle * tri
         = M_triangulation.findTriangleContains( focus_point );
 
     for ( int unum = 1; unum <= 11; ++unum )
@@ -344,7 +344,7 @@ FormationDT::getPositions( const Vector2D & focus_point,
 Vector2D
 FormationDT::interpolate( const int unum,
                           const Vector2D & focus_point,
-                          const DelaunayTriangulation::TrianglePtr tri ) const
+                          const DelaunayTriangulation::Triangle * tri ) const
 {
     if ( ! tri )
     {
