@@ -51,6 +51,9 @@ edge_pairs[3] = { std::pair< std::size_t, std::size_t >( 0, 1 ),
 
 }
 
+//#define DEBUG
+//#define DEBUG2
+
 /*-------------------------------------------------------------------*/
 /*!
 
@@ -311,10 +314,10 @@ DelaunayTriangulation::getVertex( const int id ) const
 
 */
 const
-DelaunayTriangulation::TrianglePtr
+DelaunayTriangulation::Triangle *
 DelaunayTriangulation::findTriangleContains( const Vector2D & pos ) const
 {
-    TrianglePtr tri = static_cast< TrianglePtr >( 0 );
+    Triangle * tri = static_cast< TrianglePtr >( 0 );
     findTriangleContains( pos, &tri );
     return tri;
 }
@@ -402,7 +405,12 @@ DelaunayTriangulation::compute()
         else
         {
             // type == ONLINE
-            updateOnlineVertex( &(*vit), tri );
+            if ( ! updateOnlineVertex( &(*vit), tri ) )
+            {
+                std::cerr << __FILE__ << ':' << __LINE__
+                          << " illegal vertex. index=" << loop
+                          << std::endl;
+            }
         }
 
 #ifdef DEBUG
@@ -453,7 +461,7 @@ DelaunayTriangulation::compute()
 */
 void
 DelaunayTriangulation::updateContainedVertex( const Vertex * new_vertex,
-                                              TrianglePtr tri )
+                                              const TrianglePtr tri )
 {
 #ifdef DEBUG
     std::cout << __FILE__ << ':' << __LINE__
@@ -528,9 +536,9 @@ DelaunayTriangulation::updateContainedVertex( const Vertex * new_vertex,
 /*!
 
 */
-void
+bool
 DelaunayTriangulation::updateOnlineVertex( const Vertex * new_vertex,
-                                           TrianglePtr tri )
+                                           const TrianglePtr tri )
 {
 #ifdef DEBUG
     std::cout << __FILE__ << ':' << __LINE__
@@ -539,6 +547,7 @@ DelaunayTriangulation::updateOnlineVertex( const Vertex * new_vertex,
 #endif
 
     // find edge that vertex is on-line
+    int online_count = 0;
     EdgePtr online_edge = static_cast< EdgePtr >( 0 );
     for ( std::size_t i = 0; i < 3; ++i )
     {
@@ -548,18 +557,31 @@ DelaunayTriangulation::updateOnlineVertex( const Vertex * new_vertex,
         if ( std::fabs( rel0.outerProduct( rel1 ) ) <= EPSILON )
         {
             online_edge = tri->edge( i );
-            break;
+            ++online_count;
         }
     }
 
+    if ( online_count >= 2 )
+    {
+        std::cerr << __FILE__ << ':' << __LINE__
+                  << " ***ERROR*** updateOnlineVertex()."
+                  << " detect the same vertex in old triangle="
+                  << tri->vertex( 0 )->pos()
+                  << tri->vertex( 1 )->pos()
+                  << tri->vertex( 2 )->pos()
+                  << " illegal_vertex=" << new_vertex->pos()
+                  << std::endl;
+        return false;
+    }
+
     if ( ! online_edge )
     {
         std::cerr << __FILE__ << ':' << __LINE__
-                  << " updateOnliePoint()."
+                  << " ***ERROR*** updateOnlineVertex()."
                   << " failed to find online edge."
-                  << " for vertex " << new_vertex->pos()
+                  << " illegal_vertex=" << new_vertex->pos()
                   << std::endl;
-        return;
+        return false;
     }
 #ifdef DEBUG
     std::cout << __FILE__ << ':' << __LINE__
@@ -598,10 +620,10 @@ DelaunayTriangulation::updateOnlineVertex( const Vertex * new_vertex,
         if ( ! tri_vertex )
         {
             std::cerr << __FILE__ << ':' << __LINE__
-                      << " updateOnliePoint()."
+                      << " updateOnlineVertex()."
                       << " failed to find vertex of tri."
                       << std::endl;
-            return;
+            return false;
         }
 
         EdgePtr new_edge_in_tri = createEdge( new_vertex, tri_vertex );
@@ -620,7 +642,17 @@ DelaunayTriangulation::updateOnlineVertex( const Vertex * new_vertex,
             if ( ! new_tri_in_tri[i]->circumcenter().valid() )
             {
                 std::cerr << __FILE__ << ':' << __LINE__
-                          << " updateOnlineVertex() detect illegal vertex normal"
+                          << " updateOnlineVertex() detect illegal vertex normal."
+                          << "\n  tri=" << new_tri_in_tri[i]->vertex( 0 )->pos()
+                          << new_tri_in_tri[i]->vertex( 1 )->pos()
+                          << new_tri_in_tri[i]->vertex( 2 )->pos()
+                          << "\n  new vertex pos=" << new_vertex->pos()
+                          << "\n  old_edge:" << old_edge_in_tri[i]->vertex( 0 )->pos()
+                          << "-" << old_edge_in_tri[i]->vertex( 1 )->pos()
+                          << "\n  new_edge 1:" << new_edge[i]->vertex( 0 )->pos()
+                          << "-" << new_edge[i]->vertex( 1 )->pos()
+                          << "\n  edge 3:" << new_edge_in_tri->vertex( 0 )->pos()
+                          << "-" << new_edge_in_tri->vertex( 1 )->pos()
                           << std::endl;
             }
         }
@@ -664,7 +696,7 @@ DelaunayTriangulation::updateOnlineVertex( const Vertex * new_vertex,
                       << " updateOnliePoint()."
                       << " failed to find vertex of adjacent."
                       << std::endl;
-            return;
+            return false;
         }
 
         EdgePtr new_edge_in_adjacent = createEdge( new_vertex, adjacent_vertex );
@@ -685,6 +717,16 @@ DelaunayTriangulation::updateOnlineVertex( const Vertex * new_vertex,
             {
                 std::cerr << __FILE__ << ':' << __LINE__
                           << " updateOnlineVertex() detect illegal vertex adjacent"
+                          << "\n  tri=" << new_tri_in_adjacent[i]->vertex( 0 )->pos()
+                          << new_tri_in_adjacent[i]->vertex( 1 )->pos()
+                          << new_tri_in_adjacent[i]->vertex( 2 )->pos()
+                          << "\n  new vertex pos=" << new_vertex->pos()
+                          << "\n  edge 1:" << old_edge_in_tri[i]->vertex( 0 )->pos()
+                          << "-" << old_edge_in_adjacent[i]->vertex( 1 )->pos()
+                          << "\n  edge 2:" << new_edge[i]->vertex( 0 )->pos()
+                          << "-" << new_edge[i]->vertex( 1 )->pos()
+                          << "\n  edge 3:" << new_edge_in_adjacent->vertex( 0 )->pos()
+                          << "-" << new_edge_in_adjacent->vertex( 1 )->pos()
                           << std::endl;
             }
         }
@@ -727,6 +769,7 @@ DelaunayTriangulation::updateOnlineVertex( const Vertex * new_vertex,
     }
 
     //std::cout << "updateOnlineVertex() end " << std::endl;
+    return true;
 }
 
 /*-------------------------------------------------------------------*/
@@ -750,24 +793,28 @@ DelaunayTriangulation::legalizeEdge( TrianglePtr new_tri,
     if ( ! adjacent )
     {
         // no adjacent triangle
-        //std::cout << "legalizeEdge() no adjacent " << std::endl;
-        //std::cout << "   added triangle id " << new_tri->id()
-        //          << new_tri->vertex( 0 )->pos()
-        //          << new_tri->vertex( 1 )->pos()
-        //          << new_tri->vertex( 2 )->pos()
-        //          << std::endl;
+#ifdef DEBUG2
+        std::cout << "legalizeEdge() no adjacent\n"
+                  << "   added triangle id " << new_tri->id()
+                  << new_tri->vertex( 0 )->pos()
+                  << new_tri->vertex( 1 )->pos()
+                  << new_tri->vertex( 2 )->pos()
+                  << std::endl;
+#endif
         return;
     }
 
     if ( ! adjacent->contains( new_vertex->pos() ) )
     {
         // legal triangle
-        //std::cout << "legalizeEdge() this is legal triangle " << std::endl;
-        //std::cout << "   added triangle id " << new_tri->id()
-        //          << new_tri->vertex( 0 )->pos()
-        //          << new_tri->vertex( 1 )->pos()
-        //          << new_tri->vertex( 2 )->pos()
-        //          << std::endl;
+#ifdef DEBUG2
+        std::cout << "legalizeEdge() this is a legal triangle\n"
+                  << "   added triangle id " << new_tri->id()
+                  << new_tri->vertex( 0 )->pos()
+                  << new_tri->vertex( 1 )->pos()
+                  << new_tri->vertex( 2 )->pos()
+                  << std::endl;
+#endif
         return;
     }
 
@@ -941,13 +988,13 @@ DelaunayTriangulation::findTriangleContains( const Vector2D & pos,
             return ONLINE;
         }
 
-        if ( (outer0 > 0.0 && outer1 > 0.0 && outer2 > 0.0)
-             || (outer0 < 0.0 && outer1 < 0.0 && outer2 < 0.0) )
+        if ( ( outer0 > 0.0 && outer1 > 0.0 && outer2 > 0.0 )
+             || ( outer0 < 0.0 && outer1 < 0.0 && outer2 < 0.0 ) )
         {
 #ifdef DEBUG
             std::cout << __FILE__ << ':' << __LINE__
                       << " findTriangleContains() found contained "
-                      << " pos" << vertex.pos()
+                      << " pos" << pos
                       << " triangle"
                       << tri->vertex( 0 )->pos()
                       << tri->vertex( 1 )->pos()
