@@ -32,14 +32,14 @@
 #ifndef RCSC_GEOM_DELAUNAY_TRIANGULATION_H
 #define RCSC_GEOM_DELAUNAY_TRIANGULATION_H
 
-#include <vector>
-#include <map>
-#include <algorithm>
+#include <rcsc/geom/rect_2d.h>
+#include <rcsc/geom/vector_2d.h>
 
 #include <boost/array.hpp>
 
-#include <rcsc/geom/vector_2d.h>
-#include <rcsc/geom/rect_2d.h>
+#include <algorithm>
+#include <map>
+#include <vector>
 
 namespace rcsc {
 
@@ -62,7 +62,7 @@ public:
 
     ////////////////////////////////////////////////////////////////
     /*!
-      \brief triangle's vertex data. 
+      \brief triangle's vertex data.
       This is handled as kernel point for the Voronoi diagram..
      */
     class Vertex {
@@ -590,7 +590,7 @@ public:
 
     /*!
       \brief initialize with target field rectangle data.
-      All data are cleared. 
+      All data are cleared.
       Initial triangle is crated.
      */
     void init( const Rect2D & region )
@@ -647,7 +647,7 @@ public:
       \return const pointer to the found triangle. if no triangle, NULL is returned.
      */
     const
-    TrianglePtr findTriangleContains( const Vector2D & pos ) const;
+    Triangle * findTriangleContains( const Vector2D & pos ) const;
 
     /*!
       \brief find the vertex nearest to the specified point
@@ -681,15 +681,16 @@ private:
       \param tri pointer to the triangle that contains vertex.
      */
     void updateContainedVertex( const Vertex * vertex,
-                                TrianglePtr tri );
+                                const TrianglePtr tri );
 
     /*!
       \brief update triangles by new vertex.
       \param vertex const pointer to the new vertex
       \param tri pointer to the triangle that vertex is online.
+      \return the status of vertex insertion result
      */
-    void updateOnlineVertex( const Vertex * vertex,
-                             TrianglePtr tri );
+    bool updateOnlineVertex( const Vertex * vertex,
+                             const TrianglePtr tri );
 
     /*!
       \brief check if new triangle satisfies delaunay triangle condition.
@@ -800,7 +801,7 @@ private:
       }
 
 };
- 
+
 }
 
 #endif
