@@ -111,6 +111,7 @@ public:
     /*!
       \brief constructor with another stream buffer
       \param strm filtered stream buffer.
+      \param level gzip compression level
       \param buf_size allocated buffer size (default: 8192)
 
       Default constructor creates an internal file buffer using boost::scoped_ptr.
@@ -203,6 +204,7 @@ public:
     /*!
       \brief constructor with another stream buffer
       \param strmbuf another stream buffer to be filtered
+      =param level gzip compression level
       \param buf_size allocated size of internal buffer
     */
     explicit
@@ -213,6 +215,7 @@ public:
     /*!
       \brief constructor with another stream
       \param strm another stream to be filtered
+      \param level gzip compression level
       \param buf_size allocated size of internal buffer
      */
     explicit
@@ -255,6 +258,7 @@ public:
     /*!
       \brief constructor with another stream buffer
       \param src another stream buffer to be filtered
+      \param level gzip compression level
       \param buf_size allocated size of internal buffer
      */
     explicit
@@ -265,6 +269,7 @@ public:
     /*!
       \brief constructor with another stream
       \param src another stream to be filtered
+      \param level gzip compression level
       \param buf_size allocated size of internal buffer
     */
     explicit
@@ -307,6 +312,7 @@ public:
     /*!
       \brief constructor with another stream buffer
       \param dest another stream buffer to be filtered
+      \param level gzip compression level
       \param buf_size allocated size of internal buffer
      */
     explicit
@@ -317,6 +323,7 @@ public:
     /*!
       \brief constructor with another stream
       \param dest another stream to be filtered
+      \param level gzip compression level
       \param buf_size allocated size of internal buffer
     */
     explicit
