@@ -37,6 +37,8 @@
 
 #include <string>
 #include <cstdio>
+#include <cstdlib>
+#include <cstring>
 
 namespace rcsc {
 
@@ -69,6 +71,10 @@ BodySensor::BodySensor()
     , M_attentionto_count( 0 )
     , M_tackle_expires( 0 )
     , M_tackle_count( 0 )
+    , M_none_collided( false )
+    , M_ball_collided( false )
+    , M_player_collided( false )
+    , M_post_collided( false )
 {
 
 }
@@ -104,6 +110,13 @@ BodySensor::parse1( const char * msg,
     //  (move 1) (change_view 16) (arm (movable 0) (expires 0) (target 0 0) (count 0))
     //  (focus (target none) (count 0)) (tackle (expires 0) (count 0)))
 
+    // ver. 12
+    // (sense_body 66 (view_mode high normal) (stamina 3503.4 1) (speed 0.06 -79)
+    //  (head_angle 89) (kick 4) (dash 20) (turn 24) (say 0) (turn_neck 28) (catch 0)
+    //  (move 1) (change_view 16) (arm (movable 0) (expires 0) (target 0 0) (count 0))
+    //  (focus (target none) (count 0)) (tackle (expires 0) (count 0))
+    //  (collision {none|[(ball)][player][post]}))
+
     //char ss[8];
 
     M_time = current;
@@ -140,9 +153,6 @@ BodySensor::parse1( const char * msg,
     case 'i':  // "wide"
         M_view_width = ViewWidth::WIDE;
         break;
-    case 'y': // "sync"
-        M_view_width = ViewWidth::SYNC;
-        break;
     default:
         std::cerr << "sense_body: Unknown View Width" << std::endl;
         break;
@@ -309,6 +319,16 @@ BodySensor::parse1( const char * msg,
     while ( *msg != ' ' ) ++msg; // skip "(count"
     M_tackle_count = static_cast< int >( std::strtol( msg, &next, 10 ) );
     msg = next;
+
+    if ( version < 12.0 )
+    {
+        return;
+    }
+
+    while ( *msg != '\0' && *msg != '(' ) ++msg;
+
+    parseCollision( msg );
+
 }
 
 /*-------------------------------------------------------------------*/
@@ -326,9 +346,11 @@ BodySensor::parse2( const char * msg,
 
     M_time = current;
 
+    int n_read = 0;
+
     if ( version >= 8.0
          && std::sscanf( msg,
-                         "(sense_body %ld (view_mode %7[^ ] %7[^)])"
+                         " (sense_body %ld (view_mode %7[^ ] %7[^)])"
                          " (stamina %lf %lf)"
                          " (speed %lf %lf) (head_angle %lf)"
                          " (kick %d) (dash %d) (turn %d) (say %d) (turn_neck %d)"
@@ -336,7 +358,7 @@ BodySensor::parse2( const char * msg,
                          " (arm (movable %d) (expires %d)"
                          " (target %lf %lf) (count %d))"
                          " (focus (target %[^)]) (count %d))"
-                         " (tackle (expires %d) (count %d))",
+                         " (tackle (expires %d) (count %d)) %n ",
                          &sense_time, vqual, vwidth,
                          &M_stamina, &M_effort,
                          &M_speed_mag, &M_speed_dir_relative,
@@ -349,7 +371,8 @@ BodySensor::parse2( const char * msg,
                          &M_pointto_dist, &M_pointto_dir,
                          &M_pointto_count,
                          attentionto_target , &M_attentionto_count,
-                         &M_tackle_expires, &M_tackle_count) == 25 )
+                         &M_tackle_expires, &M_tackle_count,
+                         &n_read ) == 25 )
     {
         if ( attentionto_target[0] == 'n' )
         {
@@ -375,6 +398,11 @@ BodySensor::parse2( const char * msg,
             M_attentionto_side = NEUTRAL;
             M_attentionto_unum = Unum_Unknown;
         }
+
+        if ( version >= 12.0 )
+        {
+            parseCollision( msg + n_read );
+        }
     }
     else if ( version >= 7.0
               && std::sscanf( msg,
@@ -470,9 +498,6 @@ BodySensor::parse2( const char * msg,
     case 'i':  // "wide"
         M_view_width = ViewWidth::WIDE;
         break;
-    case 'y': // "sync"
-        M_view_width = ViewWidth::SYNC;
-        break;
     default:
         std::cerr << "sense_body: Unknown View Width" << std::endl;
         break;
@@ -482,6 +507,69 @@ BodySensor::parse2( const char * msg,
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+BodySensor::parseCollision( const char * msg )
+{
+    // (collision {none|[(ball)][player][post]})
+
+    if ( std::strncmp( "(collision ", msg, 11 ) )
+    {
+        std::cerr << M_time << " sense_body. illegal collision tag ["
+                  << msg << "]" << std::endl;
+        return;
+    }
+
+    M_none_collided = false;
+    M_ball_collided = false;
+    M_player_collided = false;
+    M_post_collided = false;
+
+    msg += 11;
+    //while ( *msg != '\0' && *msg != '(' ) ++msg;
+    //while ( *msg != '\0' && *msg != ' ' ) ++msg; // skip "(collision"
+    while ( *msg == ' ' ) ++msg; // skip space
+
+    if ( ! std::strncmp( msg, "none", 4 ) )
+    {
+        M_none_collided = true;
+        return;
+    }
+
+    int n_read = 0;
+    char name[16];
+    while ( *msg != '\0' && *msg != ')' )
+    {
+        if ( std::sscanf( msg, " ( %15[^()] ) %n ",
+                          name, &n_read ) != 1 )
+        {
+            break;
+        }
+        msg += n_read;
+
+        if ( ! std::strcmp( "ball", name ) )
+        {
+            M_ball_collided = true;
+        }
+        else if ( ! std::strcmp( "player", name ) )
+        {
+            M_player_collided = true;
+        }
+        else if ( ! std::strcmp( "post", name ) )
+        {
+            M_post_collided = true;
+        }
+        else
+        {
+            std::cerr << M_time << " sense_body. Unknown collision type ["
+                      << name << "]" << std::endl;
+        }
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 std::ostream &
 BodySensor::print( std::ostream & os ) const
