@@ -34,10 +34,12 @@
 #endif
 
 #include "fullstate_sensor.h"
-#include "logger.h"
+
+#include <rcsc/common/logger.h>
 
 #include <algorithm>
 #include <iterator>
+#include <cstring>
 
 #if 0
 /*-------------------------------------------------------------------*/
@@ -268,6 +270,7 @@ FullstateSensor::parseV8( const char * msg )
             if ( *( msg + 1 ) == 'g' )
             {
                 player.goalie_ = true;
+                player.type_ = Hetero_Default;
             }
             else
             {
