@@ -44,14 +44,13 @@
 #include <boost/scoped_ptr.hpp>
 #include <boost/shared_ptr.hpp>
 
-#include <typeinfo>
-
 namespace rcsc {
 
 class DebugClient;
 class BodySensor;
 class VisualSensor;
 class AudioSensor;
+class FreeformParser;
 class FullstateSensor;
 class SeeState;
 class ArmAction;
@@ -230,10 +229,10 @@ public:
 
     /*!
       \brief register tackle command
-      \param power command argument tackle power
+      \param power_or_dir command argument tackle power or direction
       \return true if successfully registered.
     */
-    bool doTackle( const double & power );
+    bool doTackle( const double & power_or_dir );
 
     /*!
       \brief register turn_neck command.
@@ -370,8 +369,7 @@ protected:
     /*!
       \brief handle timeout event
       \param timeout_count count of timeout without sensory message.
-      \param waited_msec elapsed milli seconds sinc last sensory message.
-
+      \param waited_msec elapsed milliseconds since last sensory message.
       This method is called from BasicClient::run() method.
       Do NOT call this method by yourself!
     */
@@ -387,7 +385,7 @@ protected:
 
     /*!
       \brief register new say message parser object
-      \param parser pointer to the say mesage parser. this must be a dynamically allocated object.
+      \param parser pointer to the say mesage parser.
      */
     void addSayMessageParser( boost::shared_ptr< SayMessageParser > parser );
 
@@ -397,6 +395,12 @@ protected:
      */
     void removeSayMessageParser( const char header );
 
+    /*!
+      \brief set new freeform message parser
+      \param parser pointer to the freeform message parser.
+     */
+    void setFreeformParser( boost::shared_ptr< FreeformParser > parser );
+
 public:
     /*!
       \brief finalize all things when program quits
