@@ -723,15 +723,15 @@ public:
 class PlayerTackleCommand
     : public PlayerBodyCommand {
 private:
-    double M_power; //!< tackle power
+    double M_power_or_dir; //!< tackle power or direction
 public:
     /*!
       \brief construct with tackle power
       \param power tackle power
     */
     explicit
-    PlayerTackleCommand( const double & power )
-        : M_power( power )
+    PlayerTackleCommand( const double & power_or_dir )
+        : M_power_or_dir( power_or_dir )
       { }
 
     /*!
@@ -764,9 +764,9 @@ public:
       \return tackle power
      */
     virtual
-    double tacklePower() const
+    double tacklePowerOrDir() const
       {
-          return M_power;
+          return M_power_or_dir;
       }
 };
 
@@ -897,16 +897,20 @@ class PlayerChangeViewCommand
 private:
     ViewWidth M_width; //!< view width
     ViewQuality M_quality; //!< view quality
+    double M_version; //!< client version
 public:
     /*!
       \brief construct with view mode objects
       \param w view width object
       \param q view quality object
+      \param version client version
     */
     PlayerChangeViewCommand( const ViewWidth & w,
-                             const ViewQuality & q )
+                             const ViewQuality & q,
+                             const double & version = 8.0 )
         : M_width( w )
         , M_quality( q )
+        , M_version( version )
       { }
 
     /*!
