@@ -35,9 +35,8 @@
 
 #include "say_message_builder.h"
 
-#include "audio_codec.h"
-#include "logger.h"
-
+#include <rcsc/common/audio_codec.h>
+#include <rcsc/common/logger.h>
 #include <rcsc/common/server_param.h>
 #include <rcsc/math_util.h>
 
@@ -633,23 +632,35 @@ BallGoalieMessage::toStr( std::string & to ) const
         return false;
     }
 
+    // 74^9                       = 66540410775079424
+    // 1050*680*60*60*160*400*360 = 59222016000000000
+    // 1050*680*63*63*160*400*360 = 65292272640000000
+
+    const double max_speed = ServerParam::i().ballSpeedMax();
+    const double prec = max_speed * 2.0 / 63.0;
+
     boost::int64_t ival = 0;
     double dval = 0.0;
 
     dval = min_max( -52.5, M_ball_pos.x, 52.5 ) + 52.5;
+    // ival *= 1050
     ival += static_cast< boost::int64_t >( rint( dval / 0.1 ) );
 
     dval = min_max( -34.0, M_ball_pos.y, 34.0 ) + 34.0;
     ival *= 680;
     ival += static_cast< boost::int64_t >( rint( dval / 0.1 ) );
 
-    dval = min_max( -2.6, M_ball_vel.x, 2.6 ) + 2.6;
-    ival *= 52;
-    ival += static_cast< boost::int64_t >( rint( dval / 0.1 ) );
+    //dval = min_max( -2.6, M_ball_vel.x, 2.6 ) + 2.6;
+    //ival *= 52;
+    dval = min_max( -max_speed, M_ball_vel.x, max_speed ) + max_speed;
+    ival *= 63;
+    ival += static_cast< boost::int64_t >( rint( dval / prec ) );
 
-    dval = min_max( -2.6, M_ball_vel.y, 2.6 ) + 2.6;
-    ival *= 52;
-    ival += static_cast< boost::int64_t >( rint( dval / 0.1 ) );
+    //dval = min_max( -2.6, M_ball_vel.y, 2.6 ) + 2.6;
+    //ival *= 52;
+    dval = min_max( -max_speed, M_ball_vel.y, max_speed ) + max_speed;
+    ival *= 63;
+    ival += static_cast< boost::int64_t >( rint( dval / prec ) );
 
     dval = min_max( 52.5 - 16.0, M_goalie_pos.x, 52.5 ) - ( 52.5 - 16.0 );
     ival *= 160;
