@@ -33,7 +33,7 @@
 #define RCSC_PLAYER_PLAYER_MESSAGE_BUILDER_H
 
 #include <rcsc/geom/vector_2d.h>
-#include <rcsc/player/say_message_parser.h>
+#include <rcsc/common/say_message_parser.h>
 
 #include <string>
 
