@@ -39,8 +39,8 @@
 #include "intercept_table.h"
 #include "self_object.h"
 #include "ball_object.h"
-#include "logger.h"
 
+#include <rcsc/common/logger.h>
 #include <rcsc/common/server_param.h>
 #include <rcsc/common/player_type.h>
 #include <rcsc/soccer_math.h>
@@ -81,7 +81,7 @@ SelfIntercept::predictOneStep( std::vector< InterceptInfo > & self_cache ) const
     const Vector2D ball_next = M_world.ball().pos() + M_world.ball().vel();
     const bool goalie_mode
         = ( M_world.self().goalie()
-            && ball_next.x < ServerParam::i().ourPenaltyAreaLine()
+            && ball_next.x < ServerParam::i().ourPenaltyAreaLineX()
             && ball_next.absY() < ServerParam::i().penaltyAreaHalfWidth()
             );
     const double control_area = ( goalie_mode
@@ -625,7 +625,7 @@ SelfIntercept::predictLongStep( const int max_cycle,
         }
         const bool goalie_mode =
             ( M_world.self().goalie()
-              && ball_pos.x < ServerParam::i().ourPenaltyAreaLine()
+              && ball_pos.x < ServerParam::i().ourPenaltyAreaLineX()
               && ball_pos.absY() < ServerParam::i().penaltyAreaHalfWidth()
               );
         const double control_area = ( goalie_mode
@@ -705,7 +705,7 @@ SelfIntercept::predictFinal( std::vector< InterceptInfo > & self_cache ) const
                                ServerParam::i().ballDecay() );
     const bool goalie_mode =
         ( M_world.self().goalie()
-          && ball_final_pos.x < ServerParam::i().ourPenaltyAreaLine()
+          && ball_final_pos.x < ServerParam::i().ourPenaltyAreaLineX()
           && ball_final_pos.absY() < ServerParam::i().penaltyAreaHalfWidth()
           );
     const double control_area = ( goalie_mode
