@@ -35,8 +35,8 @@
 
 #include "stamina_model.h"
 
-#include <rcsc/param/server_param.h>
-#include <rcsc/param/player_type.h>
+#include <rcsc/common/server_param.h>
+#include <rcsc/common/player_type.h>
 #include <rcsc/game_time.h>
 
 #include <algorithm>
