@@ -36,7 +36,7 @@
 #include <rcsc/rcg/util.h>
 #include <rcsc/rcg/holder.h>
 #include <rcsc/rcg/handler.h>
-#include <rcsc/rcg/loader.h>
+#include <rcsc/rcg/reader.h>
 #include <rcsc/rcg/parser.h>
 #include <rcsc/rcg/serializer.h>
 #include <rcsc/rcg/factory.h>
