@@ -134,7 +134,7 @@ public:
       \retval false mode is incorrect, or failed to add.
     */
     virtual
-    bool addMsgInfo( const short board,
+    bool addMsgInfo( const Int16 board,
                      const std::string & msg ) = 0;
 
     /*!
@@ -193,6 +193,89 @@ public:
     virtual
     bool addPlayerParam( const player_params_t & pparams ) = 0;
 
+    //
+    // Monitor version 3
+    //
+
+    /*!
+      \brief add new display information for monitor version 3.
+      \param msg received message string
+      \retrun added result
+     */
+    bool addDisp3( const std::string & msg );
+
+    //
+    // RCG version 4
+    //
+
+    /*!
+      \brief (pure virtual) add the start of show info v4
+      \param time game time of handled data
+      \return added result
+    */
+    virtual
+    bool addShow( const int time,
+                  const ShowInfoT & show ) = 0;
+
+    /*!
+      \brief (pure virtual) add msg info v4
+      \param time game time of handled data
+      \param board parsed board info
+      \param msg parsed message string
+      \return added result
+    */
+    virtual
+    bool addMsg( const int time,
+                 const int board,
+                 const char * msg ) = 0;
+
+    /*!
+      \brief (pure virtual) add playmode info v4
+      \param time game time of handled data
+      \param pm parsed playmode type
+      \return added result
+    */
+    virtual
+    bool addPlayMode( const int time,
+                      const PlayMode pm ) = 0;
+
+    /*!
+      \brief (pure virtual0 add team info v4
+      \param time game time of handled data
+      \param team_l parsed left team data
+      \param team_r parsed right team data
+      \return added result
+    */
+    virtual
+    bool addTeam( const int time,
+                  const TeamT & team_l,
+                  const TeamT & team_r ) = 0;
+
+    /*!
+      \brief (pure virtual) add server_param
+      \param msg raw message string
+      \return added result
+    */
+    virtual
+    bool addServerParam( const std::string & msg ) = 0;
+
+    /*!
+      \brief (pure virtual) add player_param
+      \param msg raw message string
+      \return added result
+    */
+    virtual
+    bool addPlayerParam( const std::string & msg ) = 0;
+
+    /*!
+      \brief (pure virtual) add player_type
+      \param msg raw message string
+      \return added result
+    */
+    virtual
+    bool addPlayerType( const std::string & msg ) = 0;
+
+
 };
 
 } // end namespace
