@@ -43,12 +43,14 @@
 #include <rcsc/common/server_param.h>
 #include <rcsc/common/player_param.h>
 #include <rcsc/common/player_type.h>
+#include <rcsc/common/audio_memory.h>
 
 #include <rcsc/param/param_map.h>
 #include <rcsc/param/conf_file_parser.h>
 #include <rcsc/param/cmd_line_parser.h>
 
 #include <sstream>
+#include <cstring>
 
 namespace rcsc {
 
@@ -176,6 +178,10 @@ TrainerAgent::TrainerAgent()
     , M_config()
 {
     M_worldmodel.init( NEUTRAL );
+
+    boost::shared_ptr< AudioMemory > audio_memory( new AudioMemory );
+
+    M_worldmodel.setAudioMemory( audio_memory );
 }
 
 /*-------------------------------------------------------------------*/
@@ -320,7 +326,7 @@ TrainerAgent::handleMessage()
 
 */
 void
-TrainerAgent::handleTimeout( const int timeout_count,
+TrainerAgent::handleTimeout( const int /*timeout_count*/,
                              const int waited_msec )
 {
     if ( ! M_client )
@@ -608,7 +614,7 @@ TrainerAgent::analyzeHearReferee( const char * msg )
 
 */
 void
-TrainerAgent::analyzeHearPlayer( const char * msg )
+TrainerAgent::analyzeHearPlayer( const char * )
 {
     //std::cerr << "trainer: "
     //          << M_impl->current_time_
@@ -626,42 +632,43 @@ TrainerAgent::analyzeChangePlayerType( const char * msg )
     // "(ok change_player_type <teamname> <unum> <type>)"
 
     char teamname[32];
-    int unum = -1, type_num = -1;
+    int unum = -1, type = -1;
 
     std::memset( teamname, 0, 32 );
 
-    if ( std::sscanf( msg, "(ok change_player_type %31[^ ] %d %d)",
-                      teamname, &unum, &type_num ) == 3 )
+    if ( std::sscanf( msg, " ( ok change_player_type %31[^ ] %d %d )",
+                      teamname, &unum, &type ) != 3
+         || unum < 0
+         || type < 0 )
     {
-        HeteroID id = static_cast< HeteroID >( type_num );
-
-        if ( world().teamNameLeft() == teamname )
-        {
-            M_worldmodel.recvChangePlayerType( LEFT, unum, id );
-        }
-        else if ( world().teamNameRight() == teamname )
-        {
-            M_worldmodel.recvChangePlayerType( RIGHT, unum, id );
-        }
-        else if ( world().teamNameLeft().empty()
-                  && std::strlen( teamname ) != 0 )
-        {
-            M_worldmodel.setTeamName( LEFT, teamname );
-            M_worldmodel.recvChangePlayerType( LEFT, unum, id );
-        }
-        else if ( world().teamNameRight().empty()
-                  && std::strlen( teamname ) != 0 )
-        {
-            M_worldmodel.setTeamName( RIGHT, teamname );
-            M_worldmodel.recvChangePlayerType( RIGHT, unum, id );
-        }
+        std::cerr << "trainer: "
+                  << M_impl->current_time_
+                  << " ***ERROR*** parse error. "
+                  << msg
+                  << std::endl;
+        return;
     }
 
-    std::cerr << "trainer: "
-              << M_impl->current_time_
-              << " ***ERROR*** parse error. "
-              << msg
-              << std::endl;
+    if ( world().teamNameLeft() == teamname )
+    {
+        M_worldmodel.setPlayerType( LEFT, unum, type );
+    }
+    else if ( world().teamNameRight() == teamname )
+    {
+        M_worldmodel.setPlayerType( RIGHT, unum, type );
+    }
+    else if ( world().teamNameLeft().empty()
+              && std::strlen( teamname ) != 0 )
+    {
+        M_worldmodel.setTeamName( LEFT, teamname );
+        M_worldmodel.setPlayerType( LEFT, unum, type );
+    }
+    else if ( world().teamNameRight().empty()
+              && std::strlen( teamname ) != 0 )
+    {
+        M_worldmodel.setTeamName( RIGHT, teamname );
+        M_worldmodel.setPlayerType( RIGHT, unum, type );
+    }
 }
 
 /*-------------------------------------------------------------------*/
@@ -696,9 +703,11 @@ void
 TrainerAgent::analyzeServerParam( const char * msg )
 {
     ServerParam::instance().parse( msg, config().version() );
+    PlayerTypeSet::instance().resetDefaultType( ServerParam::i() );
 
     // update alarm interval
-    if ( ServerParam::i().slowDownFactor() != 1 )
+    if ( ! ServerParam::i().synchMode()
+         && ServerParam::i().slowDownFactor() > 1 )
     {
         long interval = ( ServerParam::i().simulatorStep()
                           * ServerParam::i().slowDownFactor() );
@@ -834,7 +843,10 @@ TrainerAgent::sendCommand( const TrainerCommand & com )
 
     if ( M_client->sendMessage( str.c_str() ) > 0 )
     {
-        std::cout << "OK send command [" << str << "]" << std::endl;
+        if ( str != "(done)" )
+        {
+            std::cout << "OK send command [" << str << "]" << std::endl;
+        }
         return true;
     }
 
@@ -1012,7 +1024,7 @@ TrainerAgent::doChangeMode( const PlayMode mode )
 bool
 TrainerAgent::doChangePlayerType( const std::string & teamname,
                                   const int unum,
-                                  const HeteroID type )
+                                  const int type )
 {
     TrainerChangePlayerTypeCommand com( teamname, unum, type );
     return sendCommand( com );
