@@ -30,7 +30,7 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #include <rcsc/gz/gzfstream.h>
@@ -42,6 +42,13 @@
 #include <cmath>
 #include <cstring>
 
+#ifdef HAVE_NETINET_IN_H
+#include <netinet/in.h>
+#endif
+#ifdef HAVE_WINDOWS_H
+#include <windows.h>
+#endif
+
 struct Point {
     double x;
     double y;
@@ -169,7 +176,11 @@ ResultPrinter::ResultPrinter()
 bool
 ResultPrinter::handleDispInfo( const rcsc::rcg::dispinfo_t & disp )
 {
-    return handleShowInfo( disp.body.show );
+    if ( rcsc::rcg::SHOW_MODE == htons( disp.mode ) )
+    {
+        return handleShowInfo( disp.body.show );
+    }
+    return true;
 }
 
 /*-------------------------------------------------------------------*/
@@ -244,6 +255,9 @@ ResultPrinter::handleShowInfo( const rcsc::rcg::showinfo_t & show )
 {
     M_cycle = rcsc::rcg::nstohi( show.time );
 
+    handlePlayMode( show.pmode );
+    handleTeamInfo( show.team[0], show.team[1] );
+
     if ( M_last_penalty_taker_side != rcsc::NEUTRAL )
     {
         Point ball_pos;
@@ -286,7 +300,14 @@ ResultPrinter::handleShortShowInfo2( const rcsc::rcg::short_showinfo_t2 & show )
 bool
 ResultPrinter::handlePlayMode( char playmode )
 {
-    M_playmode = static_cast< rcsc::PlayMode >( playmode );
+    rcsc::PlayMode pm = static_cast< rcsc::PlayMode >( playmode );
+
+    if ( M_playmode == pm )
+    {
+        return true;
+    }
+
+    M_playmode = pm;
 
     switch ( M_playmode ) {
     case rcsc::PM_PenaltySetup_Left:
@@ -394,8 +415,8 @@ ResultPrinter::handleEOF()
     if ( ! incomplete
          && M_playmode != rcsc::PM_TimeOver )
     {
-        if ( M_cycle % M_half_time == 0 // just a half time
-             || ( M_cycle + 1 ) % M_half_time == 0
+        if ( ( M_cycle % M_half_time == 0 // just a half time
+               || ( M_cycle + 1 ) % M_half_time == 0 )
              && ( ( M_cycle / M_half_time ) % 2 == 0 // even number halves
                   || ( ( M_cycle + 1 ) / M_half_time ) % 2 == 0 )
              && M_left_score == M_right_score ) // draw game
@@ -425,8 +446,8 @@ ResultPrinter::handleEOF()
 
 */
 bool
-ResultPrinter::handleShow( const int time,
-                           const rcsc::rcg::ShowInfoT & show )
+ResultPrinter::handleShow( const int,
+                           const rcsc::rcg::ShowInfoT & )
 {
     return true;
 }
@@ -435,9 +456,9 @@ ResultPrinter::handleShow( const int time,
 /*!
 
 */
-bool ResultPrinter::handleMsg( const int time,
-                               const int board,
-                               const char * msg )
+bool ResultPrinter::handleMsg( const int,
+                               const int,
+                               const char * )
 {
     return true;
 }
@@ -446,7 +467,7 @@ bool ResultPrinter::handleMsg( const int time,
 /*!
 
 */
-bool ResultPrinter::handlePlayMode( const int time,
+bool ResultPrinter::handlePlayMode( const int,
                                     const rcsc::PlayMode pm )
 {
     M_playmode = pm;
@@ -458,7 +479,7 @@ bool ResultPrinter::handlePlayMode( const int time,
 /*!
 
 */
-bool ResultPrinter::handleTeam( const int time,
+bool ResultPrinter::handleTeam( const int,
                                 const rcsc::rcg::TeamT & team_l,
                                 const rcsc::rcg::TeamT & team_r )
 {
@@ -480,7 +501,7 @@ bool ResultPrinter::handleTeam( const int time,
 
 */
 bool
-ResultPrinter::handleServerParam( const std::string & msg )
+ResultPrinter::handleServerParam( const std::string & )
 {
     return true;
 }
@@ -490,7 +511,7 @@ ResultPrinter::handleServerParam( const std::string & msg )
 
 */
 bool
-ResultPrinter::handlePlayerParam( const std::string & msg )
+ResultPrinter::handlePlayerParam( const std::string & )
 {
     return true;
 }
@@ -500,7 +521,7 @@ ResultPrinter::handlePlayerParam( const std::string & msg )
 
 */
 bool
-ResultPrinter::handlePlayerType( const std::string & msg )
+ResultPrinter::handlePlayerType( const std::string & )
 {
     return true;
 }
